@@ -117,10 +117,17 @@ application = app
 
     with open('run.py', 'w') as f:
         f.write(f"""import uvicorn
+from starlette_utils.utils.arg_handler import handle_args
+from starlette_utils.utils.temp_utils import delete_temp_dirs
 
 import settings
+from main import application
 
 if __name__ == '__main__':
+    delete_temp_dirs()
+
+    handle_args()
+
     uvicorn.run(
         '{project_name}.main:application',
         host="0.0.0.0",
@@ -129,8 +136,8 @@ if __name__ == '__main__':
         # loop='uvloop',
         http='httptools',
         ws='none',
-        # debug=True,
-        # reload=True,
+        debug=settings.DEBUG,
+        reload=settings.DEBUG,
     )""")
 
 
@@ -205,11 +212,11 @@ from smart7_orm.utils import discover_models, get_connection_url
 def get_config():
     config = {
         "connections": {
-            "default": get_connection_url(),
+            "default": get_connection_url().replace('///', '//'),
         },
         "apps": {
             "models": {
-                "models": ["aerich.models", *discover_models().replace('///', '//')],
+                "models": ["aerich.models", *discover_models()],
                 "default_connection": "default",
             },
         },
@@ -299,7 +306,7 @@ block_cipher = None
 
 
 a = Analysis(['run.py'],
-             pathex=['{os.path.abspath('.')}'],
+             pathex=[],
              binaries=[],
              datas=[],
              hiddenimports=['python-multipart'],
@@ -326,7 +333,7 @@ exe = EXE(pyz,
           strip=False,
           upx=True,
           upx_exclude=[],
-          runtime_tmpdir=None,
+          runtime_tmpdir='.',
           console=True,
           disable_windowed_traceback=False,
           target_arch=None,
