@@ -52,8 +52,8 @@ class BaseApiViews(HTTPEndpoint):
         except Exception as e:
             if isinstance(e, ApiException):
                 raise e
-            # raise ApiException(detail=e.__str__())
-            raise e
+            raise ApiException(detail=e.__str__())
+            # raise e
 
     @abc.abstractmethod
     async def handler(self, request: Request, *args, **kwargs):
