@@ -7,8 +7,24 @@
 # @FileName: response_results.py
 # @Software: PyCharm
 """
+import json
+import typing
 from starlette.responses import JSONResponse
 
+from starlette_utils.utils.json import JsonEncoder
+
+
+class JsonResponse(JSONResponse):
+    def render(self, content: typing.Any) -> bytes:
+        return json.dumps(
+            content,
+            ensure_ascii=False,
+            allow_nan=False,
+            indent=None,
+            separators=(",", ":"),
+            cls=JsonEncoder
+        ).encode("utf-8")
+
 
 class ResponseDict(dict):
     """
@@ -34,7 +50,7 @@ def response_result(data: dict = None, message: str = 'ok', code: int = 0, statu
     :param status_code:
     :return:
     """
-    return JSONResponse(ResponseDict(data=data, message=message, code=code), status_code=status_code)
+    return JsonResponse(ResponseDict(data=data, message=message, code=code), status_code=status_code)
 
 
 def success_result(data: dict = None):
